@@ -12,12 +12,12 @@
 
 void KbfxConfigDlgFonts::init()
 {
-	KbfxFormReady = FALSE;
+	KbfxFormReady = false;
 }
 
 void KbfxConfigDlgFonts::ChangeForm()
 {
-	KbfxFormReady = FALSE;
+	KbfxFormReady = false;
 	KbfxTheme->setText ( "<p align=left><b>" + ConfigInit().m_SpinxThemeName + "</b></p>" );
 	KbfxBoldHover->setChecked ( ConfigInit().m_fontHoverBold );
 	KbfxApplicationColor->setColor ( ConfigInit().m_fontAppNameColor );
@@ -35,7 +35,7 @@ void KbfxConfigDlgFonts::ChangeForm()
 	KbfxFont_plugin->setFont ( ConfigInit().m_pluginNameFont );
 	KbfxTooltipColor->setColor ( ConfigInit().m_fontTooltipColor );
 	KbfxFont_tooltip->setFont ( ConfigInit().m_fontTooltipFont );
-	KbfxFormReady = TRUE;
+	KbfxFormReady = true;
 }
 
 void KbfxConfigDlgFonts::KbfxApplicationColorSelected ( const TQColor &color )
@@ -117,7 +117,7 @@ void KbfxConfigDlgFonts::KbfxExportFileAction()
 	                                     "*.*|" + tr2i18n("All files"),
 	                                     0,
 	                                     0,
-	                                     TRUE);
+	                                     true);
 	  KbfxExportFontRcDialog.setOperationMode(KFileDialog::Saving);
 	  KbfxExportFontRcDialog.setCaption(tr2i18n("Select Folder to export kbfxfontrc file"));
 	  KbfxExportFontRcDialog.setMode(KFile::Directory);
