@@ -635,7 +635,7 @@ bool KbfxConfigDlgLayout::KbfxMessage()
 	                   tr2i18n ( "Prepare" ) );
 
 	if ( messageBoxReturn == KMessageBox::Cancel )
-		return FALSE;
+		return false;
 
-	return TRUE;
+	return true;
 }
