@@ -41,7 +41,7 @@ void KbfxKioDownload::KbfxKioDownloadStart ( TQString &url )
 	TDEIO::Job *download_job = TDEIO::file_copy ( KURL ( url ),
 	                         KURL ( m_KbfxBrowserTmpFile ),
 	                         -1,
-	                         TRUE );
+	                         true );
 	connect ( download_job, TQ_SIGNAL ( result ( TDEIO::Job* ) ),
 	          this, TQ_SLOT ( KbfxBrowserResult ( TDEIO::Job * ) ) );
 }
