@@ -35,7 +35,7 @@
 class KbfxPlasmaCanvasAbstractItem:public TQObject,public TQCanvasSprite
 {
 
-		Q_OBJECT
+		TQ_OBJECT
   
 
 	public:
