@@ -40,7 +40,7 @@
 class KbfxPlasmaCanvasItem:public KbfxPlasmaCanvasAbstractItem
 {
 
-		Q_OBJECT
+		TQ_OBJECT
   
 
 	public:
