@@ -51,7 +51,7 @@ class TQCanvasView;
 
 class KbfxPlasmaCanvasView : public TQCanvasView
 {
-		Q_OBJECT
+		TQ_OBJECT
   
 
 	public:
