@@ -42,7 +42,7 @@
 class KbfxPlasmaIndexView : public TQCanvasView
 {
 
-		Q_OBJECT
+		TQ_OBJECT
   
 
 	public:
